pub struct DeviceExchangeVectorRequest {
pub txdata: Vec<u8>,
}Fields
txdata: Vec<u8>Trait Implementations
Sourceimpl Clone for DeviceExchangeVectorRequest
impl Clone for DeviceExchangeVectorRequest
Sourcefn clone(&self) -> DeviceExchangeVectorRequest
fn clone(&self) -> DeviceExchangeVectorRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceExchangeVectorRequest
impl Debug for DeviceExchangeVectorRequest
Sourceimpl<'a, ___E> Encode<DeviceExchangeVectorRequest<'static>, ___E> for &'a DeviceExchangeVectorRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<DeviceExchangeVectorRequest<'static>, ___E> for &'a DeviceExchangeVectorRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceExchangeVectorRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceExchangeVectorRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceExchangeVectorRequest<'static>, ___E> for DeviceExchangeVectorRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<DeviceExchangeVectorRequest<'static>, ___E> for DeviceExchangeVectorRequestwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceExchangeVectorRequest<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceExchangeVectorRequest<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceExchangeVectorRequest<'static>>, ___E> for &'a DeviceExchangeVectorRequestwhere
___E: Encoder + ?Sized,
&'a DeviceExchangeVectorRequest: Encode<DeviceExchangeVectorRequest<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceExchangeVectorRequest<'static>>, ___E> for &'a DeviceExchangeVectorRequestwhere
___E: Encoder + ?Sized,
&'a DeviceExchangeVectorRequest: Encode<DeviceExchangeVectorRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceExchangeVectorRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceExchangeVectorRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceExchangeVectorRequest<'static>>, ___E> for DeviceExchangeVectorRequestwhere
___E: Encoder + ?Sized,
DeviceExchangeVectorRequest: Encode<DeviceExchangeVectorRequest<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceExchangeVectorRequest<'static>>, ___E> for DeviceExchangeVectorRequestwhere
___E: Encoder + ?Sized,
DeviceExchangeVectorRequest: Encode<DeviceExchangeVectorRequest<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceExchangeVectorRequest<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceExchangeVectorRequest<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<DeviceExchangeVectorRequest<'de>> for DeviceExchangeVectorRequest
impl<'de> FromWire<DeviceExchangeVectorRequest<'de>> for DeviceExchangeVectorRequest
Sourcefn from_wire(wire: DeviceExchangeVectorRequest<'de>) -> Self
fn from_wire(wire: DeviceExchangeVectorRequest<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DeviceExchangeVectorRequest<'de>> for DeviceExchangeVectorRequest
impl<'de> FromWireRef<DeviceExchangeVectorRequest<'de>> for DeviceExchangeVectorRequest
Sourcefn from_wire_ref(wire: &DeviceExchangeVectorRequest<'de>) -> Self
fn from_wire_ref(wire: &DeviceExchangeVectorRequest<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceExchangeVectorRequest
impl Hash for DeviceExchangeVectorRequest
Sourceimpl Ord for DeviceExchangeVectorRequest
impl Ord for DeviceExchangeVectorRequest
Sourcefn cmp(&self, other: &DeviceExchangeVectorRequest) -> Ordering
fn cmp(&self, other: &DeviceExchangeVectorRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceExchangeVectorRequest
impl PartialEq for DeviceExchangeVectorRequest
Sourcefn eq(&self, other: &DeviceExchangeVectorRequest) -> bool
fn eq(&self, other: &DeviceExchangeVectorRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceExchangeVectorRequest
impl PartialOrd for DeviceExchangeVectorRequest
impl Eq for DeviceExchangeVectorRequest
impl StructuralPartialEq for DeviceExchangeVectorRequest