#[repr(C)]pub struct DeviceTransmitVectorResponse {
pub status: Status,
}Fields
status: StatusTrait Implementations
Sourceimpl Clone for DeviceTransmitVectorResponse
impl Clone for DeviceTransmitVectorResponse
Sourcefn clone(&self) -> DeviceTransmitVectorResponse
fn clone(&self) -> DeviceTransmitVectorResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceTransmitVectorResponse
impl Debug for DeviceTransmitVectorResponse
Sourceimpl<'a, ___E> Encode<DeviceTransmitVectorResponse, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceTransmitVectorResponse, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceTransmitVectorResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceTransmitVectorResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceTransmitVectorResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceTransmitVectorResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceTransmitVectorResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceTransmitVectorResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, DeviceTransmitVectorResponse>, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: Encoder + ?Sized,
&'a DeviceTransmitVectorResponse: Encode<DeviceTransmitVectorResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, DeviceTransmitVectorResponse>, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: Encoder + ?Sized,
&'a DeviceTransmitVectorResponse: Encode<DeviceTransmitVectorResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceTransmitVectorResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceTransmitVectorResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, DeviceTransmitVectorResponse>, ___E> for DeviceTransmitVectorResponsewhere
___E: Encoder + ?Sized,
DeviceTransmitVectorResponse: Encode<DeviceTransmitVectorResponse, ___E>,
impl<___E> EncodeOption<Box<'static, DeviceTransmitVectorResponse>, ___E> for DeviceTransmitVectorResponsewhere
___E: Encoder + ?Sized,
DeviceTransmitVectorResponse: Encode<DeviceTransmitVectorResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, DeviceTransmitVectorResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, DeviceTransmitVectorResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
impl FromWire<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceTransmitVectorResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceTransmitVectorResponse, Self>
Sourcefn from_wire(wire: DeviceTransmitVectorResponse) -> Self
fn from_wire(wire: DeviceTransmitVectorResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
impl FromWireRef<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
Sourcefn from_wire_ref(wire: &DeviceTransmitVectorResponse) -> Self
fn from_wire_ref(wire: &DeviceTransmitVectorResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DeviceTransmitVectorResponse
impl Hash for DeviceTransmitVectorResponse
Sourceimpl Ord for DeviceTransmitVectorResponse
impl Ord for DeviceTransmitVectorResponse
Sourcefn cmp(&self, other: &DeviceTransmitVectorResponse) -> Ordering
fn cmp(&self, other: &DeviceTransmitVectorResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceTransmitVectorResponse
impl PartialEq for DeviceTransmitVectorResponse
Sourcefn eq(&self, other: &DeviceTransmitVectorResponse) -> bool
fn eq(&self, other: &DeviceTransmitVectorResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceTransmitVectorResponse
impl PartialOrd for DeviceTransmitVectorResponse
impl Copy for DeviceTransmitVectorResponse
impl Eq for DeviceTransmitVectorResponse
impl StructuralPartialEq for DeviceTransmitVectorResponse