#[repr(C)]pub struct DeviceTransmitVectorResponse {
pub status: Status,
}Expand description
The wire type corresponding to DeviceTransmitVectorResponse.
Fields
status: StatusTrait Implementations
Sourceimpl Clone for DeviceTransmitVectorResponse
impl Clone for DeviceTransmitVectorResponse
Sourcefn clone(&self) -> DeviceTransmitVectorResponse
fn clone(&self) -> DeviceTransmitVectorResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceTransmitVectorResponse
impl Constrained for DeviceTransmitVectorResponse
Sourceimpl Debug for DeviceTransmitVectorResponse
impl Debug for DeviceTransmitVectorResponse
Sourceimpl<___D> Decode<___D> for DeviceTransmitVectorResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceTransmitVectorResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceTransmitVectorResponse, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceTransmitVectorResponse, ___E> for &'a DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceTransmitVectorResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceTransmitVectorResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceTransmitVectorResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceTransmitVectorResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceTransmitVectorResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceTransmitVectorResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
impl<___E, T0> Encode<DeviceTransmitVectorResponse, ___E> for DeviceTransmitVectorResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceTransmitVectorResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceTransmitVectorResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
impl FromWire<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceTransmitVectorResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceTransmitVectorResponse, Self>
Sourcefn from_wire(wire: DeviceTransmitVectorResponse) -> Self
fn from_wire(wire: DeviceTransmitVectorResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
impl FromWireRef<DeviceTransmitVectorResponse> for DeviceTransmitVectorResponse
Sourcefn from_wire_ref(wire: &DeviceTransmitVectorResponse) -> Self
fn from_wire_ref(wire: &DeviceTransmitVectorResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceTransmitVectorResponse
impl IntoNatural for DeviceTransmitVectorResponse
Sourcetype Natural = DeviceTransmitVectorResponse
type Natural = DeviceTransmitVectorResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceTransmitVectorResponse
impl Wire for DeviceTransmitVectorResponse
Sourcetype Narrowed<'de> = DeviceTransmitVectorResponse
type Narrowed<'de> = DeviceTransmitVectorResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.